from setuptools import setup

setup(name='distribution_of_probability',
      version='1.0',
      description='Gaussian distributions',
      packages=['distribution_of_probability'],
      zip_safe=False)
